// Copyright 2019 Google LLC.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

syntax = "proto3";

package google.cloud.datacatalog.v1beta1;

import "google/protobuf/timestamp.proto";

option cc_enable_arenas = true;
option go_package = "google.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog";
option java_multiple_files = true;
option java_package = "com.google.cloud.datacatalog";

// Timestamps about this resource according to a particular system.
message SystemTimestamps {
  // Output only. The creation time of the resource within the given system.
  google.protobuf.Timestamp create_time = 1;

  // Output only. The last-modified time of the resource within the given
  // system.
  google.protobuf.Timestamp update_time = 2;

  // Output only. The expiration time of the resource within the given system.
  google.protobuf.Timestamp expire_time = 3;
}
